JikanEx.Exception exception (JikanEx v0.1.5) View Source

Defines the API Error class. It has two fields, a message and response. message is the error message from the Jikan response, and the response is the Response map from JikanEx.Request

Link to this section Summary

Functions

Error raised by bang functions in JikanEx.Request

Link to this section Functions

Error raised by bang functions in JikanEx.Request